[![Downloads](https://pepy.tech/badge/nornir-salt)](https://pepy.tech/project/nornir-salt)
[![PyPI versions](https://img.shields.io/pypi/pyversions/nornir-salt.svg)](https://pypi.python.org/pypi/nornir-salt/)
[![Documentation status](https://readthedocs.org/projects/nornir-salt/badge/?version=latest)](http://nornir-salt.readthedocs.io/?badge=latest)

# nornir-salt

Collection of Nornir plugins for [SALTSTACK Nornir Proxy Minion modules](https://github.com/dmulyalin/salt-nornir).

All plugins and functions can be used with Nornir directly unless stated otherwise.

Refer to [documentation](https://nornir-salt.readthedocs.io/en/latest/) for additional information.

# Contributing

Issues, bug reports and feature requests are welcomed.
